diff --git a/dumux/implicit/2pnc/2pncproperties.hh b/dumux/implicit/2pnc/2pncproperties.hh
index 7f4e31f51450585deedf65d47c68037728d04e79..ad149cbfc4cbf03790c2e8b060509b8ed18d15b2 100644
--- a/dumux/implicit/2pnc/2pncproperties.hh
+++ b/dumux/implicit/2pnc/2pncproperties.hh
@@ -30,6 +30,7 @@
 #define DUMUX_2PNC_PROPERTIES_HH
 
 #include <dumux/implicit/box/boxproperties.hh>
+#include <dumux/implicit/cellcentered/ccproperties.hh>
 
 namespace Dumux
 {
@@ -40,8 +41,10 @@ namespace Properties
 // Type tags
 //////////////////////////////////////////////////////////////////
 
-//! The type tag for the isothermal two phase n component problems
-NEW_TYPE_TAG(BoxTwoPNC, INHERITS_FROM(BoxModel));
+//! The type tag for the implicit isothermal two phase n component problems
+NEW_TYPE_TAG(TwoPNC);
+NEW_TYPE_TAG(BoxTwoPNC, INHERITS_FROM(BoxModel, TwoPNC));
+NEW_TYPE_TAG(CCTwoPNC, INHERITS_FROM(CCModel, TwoPNC));
 
 //////////////////////////////////////////////////////////////////
 // Property tags
diff --git a/dumux/implicit/2pnc/2pncpropertydefaults.hh b/dumux/implicit/2pnc/2pncpropertydefaults.hh
index c5620b4d4217b455cfaa3084b728689d2cd7d4a8..c0e7cbd46f498c7ea1b38f1a3f52d88b393b79f6 100644
--- a/dumux/implicit/2pnc/2pncpropertydefaults.hh
+++ b/dumux/implicit/2pnc/2pncpropertydefaults.hh
@@ -54,7 +54,7 @@ namespace Properties {
  * We just forward the number from the fluid system
  *
  */
-SET_PROP(BoxTwoPNC, NumComponents)
+SET_PROP(TwoPNC, NumComponents)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
@@ -64,7 +64,7 @@ public:
 
 };
 //! Set as default that no component mass balance is replaced by the total mass balance
-SET_PROP(BoxTwoPNC, ReplaceCompEqIdx)
+SET_PROP(TwoPNC, ReplaceCompEqIdx)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
@@ -73,7 +73,7 @@ public:
     static const int value = FluidSystem::numComponents;
 };
 //! The major components belonging to the existing phases are mentioned here e.g., 2 for water and air being the major component in the liquid and gas phases in a 2 phase system 
-SET_PROP(BoxTwoPNC, NumMajorComponents)
+SET_PROP(TwoPNC, NumMajorComponents)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
@@ -90,7 +90,7 @@ public:
  * We just forward the number from the fluid system and use an static
  * assert to make sure it is 2.
  */
-SET_PROP(BoxTwoPNC, NumPhases)
+SET_PROP(TwoPNC, NumPhases)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
@@ -103,7 +103,7 @@ public:
 /*!
  * \brief Set the property for the number of equations: For each existing component one equation has to be solved.
  */
-SET_PROP(BoxTwoPNC, NumEq)
+SET_PROP(TwoPNC, NumEq)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(FluidSystem)) FluidSystem;
@@ -113,10 +113,10 @@ public:
 };
 
 //! Set the default formulation to pl-Sg: This can be over written in the problem.
-SET_INT_PROP(BoxTwoPNC, Formulation, TwoPNCFormulation::plSg);
+SET_INT_PROP(TwoPNC, Formulation, TwoPNCFormulation::plSg);
 
 //! Set the property for the material parameters by extracting it from the material law.
-SET_PROP(BoxTwoPNC, MaterialLawParams)
+SET_PROP(TwoPNC, MaterialLawParams)
 {
 private:
     typedef typename GET_PROP_TYPE(TypeTag, PTAG(MaterialLaw)) MaterialLaw;
@@ -126,45 +126,45 @@ public:
 };
 
 //! Use the 2pnc local residual operator
-SET_TYPE_PROP(BoxTwoPNC,
+SET_TYPE_PROP(TwoPNC,
               LocalResidual,
               TwoPNCLocalResidual<TypeTag>);
 
 //! Use the 2pnc newton controller
-SET_TYPE_PROP(BoxTwoPNC, NewtonController, TwoPNCNewtonController<TypeTag>);
+SET_TYPE_PROP(TwoPNC, NewtonController, TwoPNCNewtonController<TypeTag>);
 
 //! the Model property
-SET_TYPE_PROP(BoxTwoPNC, Model, TwoPNCModel<TypeTag>);
+SET_TYPE_PROP(TwoPNC, Model, TwoPNCModel<TypeTag>);
 
 //! the VolumeVariables property
-SET_TYPE_PROP(BoxTwoPNC, VolumeVariables, TwoPNCVolumeVariables<TypeTag>);
+SET_TYPE_PROP(TwoPNC, VolumeVariables, TwoPNCVolumeVariables<TypeTag>);
 
 //! the FluxVariables property
-SET_TYPE_PROP(BoxTwoPNC, FluxVariables, TwoPNCFluxVariables<TypeTag>);
+SET_TYPE_PROP(TwoPNC, FluxVariables, TwoPNCFluxVariables<TypeTag>);
 
 //! define the base flux variables to realize Darcy flow
-SET_TYPE_PROP(BoxTwoPNC, BaseFluxVariables, ImplicitDarcyFluxVariables<TypeTag>);
+SET_TYPE_PROP(TwoPNC, BaseFluxVariables, ImplicitDarcyFluxVariables<TypeTag>);
 
 //! the upwind weight for the mass conservation equations.
-SET_SCALAR_PROP(BoxTwoPNC, ImplicitMassUpwindWeight, 1.0);
+SET_SCALAR_PROP(TwoPNC, ImplicitMassUpwindWeight, 1.0);
 
 //! Set default mobility upwind weight to 1.0, i.e. fully upwind
-SET_SCALAR_PROP(BoxTwoPNC, ImplicitMobilityUpwindWeight, 1.0);
+SET_SCALAR_PROP(TwoPNC, ImplicitMobilityUpwindWeight, 1.0);
 
 //! The indices required by the isothermal 2pnc model
-SET_TYPE_PROP(BoxTwoPNC, Indices, TwoPNCIndices <TypeTag, /*PVOffset=*/0>);
+SET_TYPE_PROP(TwoPNC, Indices, TwoPNCIndices <TypeTag, /*PVOffset=*/0>);
 
 //! Use the ImplicitSpatialParams by default
-SET_TYPE_PROP(BoxTwoPNC, SpatialParams, ImplicitSpatialParams<TypeTag>);
+SET_TYPE_PROP(TwoPNC, SpatialParams, ImplicitSpatialParams<TypeTag>);
 
 //! Enable gravity by default
-SET_BOOL_PROP(BoxTwoPNC, ProblemEnableGravity, true);
+SET_BOOL_PROP(TwoPNC, ProblemEnableGravity, true);
 
 //! Disable velocity output by default
-SET_BOOL_PROP(BoxTwoPNC, VtkAddVelocity, false);
+SET_BOOL_PROP(TwoPNC, VtkAddVelocity, false);
 
 //! disable electro-chemistry by default
-SET_BOOL_PROP(BoxTwoPNC, useElectrochem, false);
+SET_BOOL_PROP(TwoPNC, useElectrochem, false);
 
 }
 
diff --git a/dumux/implicit/2pncmin/2pncminfluxvariables.hh b/dumux/implicit/2pncmin/2pncminfluxvariables.hh
index 4b7ce4c298bae2c392337f9974dc4786f35ff524..c48b67bf90c9b541d43f7b41f5040a1cb0b3ffc6 100644
--- a/dumux/implicit/2pncmin/2pncminfluxvariables.hh
+++ b/dumux/implicit/2pncmin/2pncminfluxvariables.hh
@@ -1,4 +1,4 @@
-// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+// -**- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 // vi: set et ts=4 sw=4 sts=4:
 /*****************************************************************************
  *   See the file COPYING for full copying permissions.                      *
diff --git a/dumux/implicit/2pncmin/2pncminproperties.hh b/dumux/implicit/2pncmin/2pncminproperties.hh
index f89c1538ad9cd49a00846d05a7361d008467233a..9f410f690ce2de62c4b91faf7b88c6de559943bf 100644
--- a/dumux/implicit/2pncmin/2pncminproperties.hh
+++ b/dumux/implicit/2pncmin/2pncminproperties.hh
@@ -1,4 +1,4 @@
-// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+// -**- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 // vi: set et ts=4 sw=4 sts=4:
 /*****************************************************************************
  *   See the file COPYING for full copying permissions.                      *
diff --git a/dumux/implicit/2pncmin/2pncminpropertydefaults.hh b/dumux/implicit/2pncmin/2pncminpropertydefaults.hh
index 10eaa8ce1b24e5a0e2821116165cd82e25b95002..ad4412120d2e2c7b3afb6364d03546720e98020a 100644
--- a/dumux/implicit/2pncmin/2pncminpropertydefaults.hh
+++ b/dumux/implicit/2pncmin/2pncminpropertydefaults.hh
@@ -1,4 +1,4 @@
-// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+// -**- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 // vi: set et ts=4 sw=4 sts=4:
 /*****************************************************************************
  *   See the file COPYING for full copying permissions.                      *
diff --git a/dumux/implicit/2pncmin/2pncminvolumevariables.hh b/dumux/implicit/2pncmin/2pncminvolumevariables.hh
index 97e583ab576eb6385e957e434ccaacd10bd56506..28df29458c0c8555a04ef5a2f98b6647baca81f8 100644
--- a/dumux/implicit/2pncmin/2pncminvolumevariables.hh
+++ b/dumux/implicit/2pncmin/2pncminvolumevariables.hh
@@ -1,4 +1,4 @@
-// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+// -**- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 // vi: set et ts=4 sw=4 sts=4:
 /*****************************************************************************
  *   See the file COPYING for full copying permissions.                      *
diff --git a/dumux/implicit/2pnc/2pncvolumevariables.hh b/dumux/implicit/2pnc/2pncvolumevariables.hh
index 95f63f22fe91d726b7c62c776cda687b820ec167..194e52e26d184281798f45867cbd9dff37f792b3 100644
--- a/dumux/implicit/2pnc/2pncvolumevariables.hh
+++ b/dumux/implicit/2pnc/2pncvolumevariables.hh
@@ -98,8 +98,8 @@ class TwoPNCVolumeVariables : public ImplicitVolumeVariables<TypeTag>
 
     typedef typename GridView::template Codim<0>::Entity Element;
     typedef typename Grid::ctype CoordScalar;
-    typedef Dumux::Miscible2pNcComposition<Scalar, FluidSystem> Miscible2pNcComposition;
-    typedef Dumux::ComputeFromReferencePhase2pNc<Scalar, FluidSystem> ComputeFromReferencePhase2pNc;
+    typedef Dumux::miscible2pncComposition<Scalar, FluidSystem> miscible2pncComposition;
+    typedef Dumux::computeFromReferencePhase2pnc<Scalar, FluidSystem> computeFromReferencePhase2pnc;
 
     enum { isBox = GET_PROP_VALUE(TypeTag, ImplicitIsBox) };
     enum { dofCodim = isBox ? dim : 0 };
@@ -259,13 +259,13 @@ public:
             // constraint solver
 
             // set the known mole fractions in the fluidState so that they
             // can be used by the Miscible2pNcComposition constraint solver
             for (int compIdx=numMajorComponents; compIdx<numComponents; ++compIdx)
             {
                 fluidState.setMoleFraction(wPhaseIdx, compIdx, primaryVariables[compIdx]);
             }
 
-            Miscible2pNcComposition::solve(fluidState,
+            miscible2pncComposition::solve(fluidState,
                         paramCache,
                         wPhaseIdx,	//known phaseIdx
                         /*setViscosity=*/true,
@@ -297,8 +297,8 @@ public:
 
             // calculate the composition of the remaining phases (as
             // well as the densities of all phases). this is the job
-            // of the "ComputeFromReferencePhase2pNc" constraint solver
-                ComputeFromReferencePhase2pNc::solve(fluidState,
+            // of the "computeFromReferencePhase2pnc" constraint solver
+                computeFromReferencePhase2pnc::solve(fluidState,
                                                 paramCache,
                                                 nPhaseIdx,
                                                 /*setViscosity=*/true,
@@ -333,8 +333,8 @@ public:
             
             // calculate the composition of the remaining phases (as
             // well as the densities of all phases). this is the job
-            // of the "ComputeFromReferencePhase2pNc" constraint solver
-            ComputeFromReferencePhase2pNc::solve(fluidState,
+            // of the "computeFromReferencePhase2pnc" constraint solver
+            computeFromReferencePhase2pnc::solve(fluidState,
                                                 paramCache,
                                                 wPhaseIdx,
                                                 /*setViscosity=*/true,
@@ -259,13 +259,13 @@ public:
 
             // set the known mole fractions in the fluidState so that they
-            // can be used by the Miscible2pNcComposition constraint solver
+            // can be used by the miscible2pncComposition constraint solver
             for (int compIdx=numMajorComponents; compIdx<numComponents; ++compIdx)
             {